Hi

 

On this server we upgraded from 9.4.3b3 to 9.5.1P1

 

Response time went from 3 ms to 900 ms

 

What makes this server different is that it runs a wedge that checks for
nxdomain

 

Is there a security enhancement or something new that this version of
bind deals differently with all queries originating from the same IP
since the wedge is sourcing all the queries.

 

Bruce

 

Bruce Hayward, MTS Allstream Inc., (c) 204-792-9174 (p) 204-958-1983 (e)
[email protected] 

 

 

_______________________________________________
bind-users mailing list
[email protected]
https://lists.isc.org/mailman/listinfo/bind-users

Reply via email to